require 'spec_helper'

describe Silverdot::ActionViewExtension do
  before :each do
    helper.lookup_context.prefixes = ''
    helper.lookup_context.view_paths += Dir["#{Rails.root}/views"]
  end

  describe "#emboss" do
    describe 'spec/fake_app/views/single.html.erb' do
      subject { helper.emboss('single', with: :single) }
      it { should eq("<p>{{ single }}</p>\n") }
    end

    describe 'spec/fake_app/views/object.html.erb' do
      subject { helper.emboss('object', with: :object) }
      it { should eq("<ul><li>{{ object.name }}</li><li>{{ object.age }}</li></ul>\n") }
    end

    describe 'spec/fake_app/views/link.html.erb' do
      subject { helper.emboss('link', with: :link) }
      it { should eq("<a href=\"{{ link.url }}\">{{ link.name }}</a>\n") }
    end

    describe 'spec/face_app/views/_image.html.erb' do
      subject { helper.emboss('image', with: :account) }
      it { should =~ /\A<img[\s\S]*>\n?\z/ }
      it { should =~ /src="{{ account.avatar.src }}"/ }
      it { should =~ /alt="{{ account.avatar.alt }}"/ }
    end

    describe 'spec/fake_app/views/locale.html.erb' do
      subject { helper.emboss('locale', with: :locale) }
      it { should eq("{{ locale.created_at }}\n") }
    end

    describe 'with jst option' do
      it 'compiles by ejs' do
        ::EJS.should_receive(:compile).with("<p>{{ single }}</p>\n", Silverdot.ejs_options).and_return('result')
        helper.emboss('single', with: :single, jst: true)
      end

      describe 'Render <script> tag' do
        subject { helper.emboss('single', with: :single, jst: true) }
        it { should =~ /\A<script>[\s\S]+<\/script>\n?\z/ }
        it { should =~ /JST\['single'\] = / }
      end
    end

    describe 'without ejs option' do
      it 'does not compile by ejs' do
        ::EJS.should_not_receive(:compile)
        helper.emboss('single', with: :single, ejs: false)
      end
    end
  end
end
